@@ -138,17 +138,17 @@ class LineList:
         (
             np.record,
             [
-                (("wlc", "WLC"), ">f8"),
-                (("wll", "WLL"), ">f8"),
-                (("posc", "POSC"), ">f8"),
-                (("posm", "POSM"), ">f8"),
-                (("xfirst", "XFIRST"), ">i2"),
-                (("xlast", "XLAST"), ">i2"),
-                (("approx", "APPROX"), "O"),
-                (("width", "WIDTH"), ">f8"),
-                (("height", "HEIGHT"), ">f8"),
-                (("order", "ORDER"), ">i2"),
-                ("flag", "?"),
+                (("wlc", "WLC"), ">f8"), # Wavelength (before fit)
+                (("wll", "WLL"), ">f8"), # Wavelength (after fit)
+                (("posc", "POSC"), ">f8"), # Pixel Position (before fit)
+                (("posm", "POSM"), ">f8"), # Pixel Position (after fit)
+                (("xfirst", "XFIRST"), ">i2"), # first pixel of the line
+                (("xlast", "XLAST"), ">i2"), # last pixel of the line
+                (("approx", "APPROX"), "O"), # ???
+                (("width", "WIDTH"), ">f8"), # width of the line in pixels
+                (("height", "HEIGHT"), ">f8"), # relative strength of the line
+                (("order", "ORDER"), ">i2"), # echelle order the line is found in
+                ("flag", "?"), # flag that tells us if we should use the line or not
             ],
         )
     )
@@ -1175,6 +1175,11 @@ class WavelengthCalibration:
             new_peaks[j] = coef[1] + p - width
 
         n = np.arange(len(peaks))
+        
+        # keep peaks within the range
+        mask = (new_peaks > 0) & (new_peaks < len(c))
+        n, new_peaks = n[mask], new_peaks[mask]
+
         return n, new_peaks
 
     def frequency_comb(self, comb, wave, lines=None):
@@ -1199,9 +1204,19 @@ class WavelengthCalibration:
 
             # fr: repeating frequency
             # fd: anchor frequency of this order, needs to be shifted to the absolute reference frame
-            res = Polynomial.fit(n, f_old, deg=1, domain=[])
-            fd, fr = res.coef
-            n = np.round((f_old - fd) / fr)
+            # res = Polynomial.fit(n, f_old, deg=1, domain=[])
+            # fd, fr = res.coef
+
+            fr = np.median(np.diff(f_old))
+            fd = np.median(f_old % fr)
+            n_raw = (f_old - fd) / fr
+            n = np.round(n_raw)
+
+            if np.any(np.abs(n_raw - n) > 0.3):
+                logger.warning("Bad peaks detected in the frequency comb")
+
+            n -= n[0]
+
             res = Polynomial.fit(n, f_old, deg=1, domain=[])
             fd, fr = res.coef
 
@@ -1229,6 +1244,8 @@ class WavelengthCalibration:
         # Merge Data
         n_all = np.concatenate(n_all)
         f_all = np.concatenate(f_all)
+        pixel = np.concatenate(pixel)
+        order = np.concatenate(order)
 
         # Fit f0 and fr to all data
         # (fr, f0), cov = np.polyfit(n_all, f_all, deg=1, cov=True)
@@ -1240,8 +1257,7 @@ class WavelengthCalibration:
 
         # All peaks are then given by f0 + n * fr
         wavelengths = speed_of_light / (f0 + n_all * fr)
-        pixel = np.concatenate(pixel)
-        order = np.concatenate(order)
+
         flag = np.full(len(wavelengths), True)
         laser_lines = np.rec.fromarrays(
             (wavelengths, pixel, pixel, order, flag),
